
Include "data_condo.geo";

Group{
  Domaine = Region[{AIR,DIELECTRIQUE}];
  Dielectrique = Region[{DIELECTRIQUE}];

  Masse = Region[{MASSE}];
  DeltaV = Region[{DELTAV}];
  Armatures =  Region[{MASSE,DELTAV}];
  Dirichlet = Region[{BORDS}];
}

Function{
  eps[#{AIR}] = eps0;
  eps[#{DIELECTRIQUE}] = eps0*epsr;
  capa_ana = eps0*epsr*2*Pi*h/Log[(Ri+ep+epd)/(Ri+ep)];
  DefineConstant[  
    cana = {capa_ana, Name "Modele/Resultats/0Capa analytique (F)", 
      ReadOnly 1, Highlight "Pink"}
  ];
}


Jacobian{
  { Name Jvol;
    Case {
      { Region All ; Jacobian VolAxi ; }
    }
  }
}

Integration {
  { Name Integ;
    Case { 
      {Type Gauss;
	Case { 
	  { GeoElement Line ; NumberOfPoints 2; }
	  { GeoElement Triangle ; NumberOfPoints 6; } }
      }
    }
  }
}

Constraint {	
  { Name TensionsNulles ;
    Case {      
      { Region Dirichlet ; Type Assign ; Value 0 ; }
    }
  }
   { Name TensionImposee ;
    Case {      
      If (Flag_alim == 0) 
	{ Region DeltaV ; Type Assign ; Value V1 ; }
      EndIf
      { Region Masse ; Type Assign ; Value 0 ; }  
    }
  }
  { Name ChargeImposee ;
    Case {
      If (Flag_alim == 1) 
	{ Region DeltaV ; Type Assign ; Value Q1/(2*Pi)/2 ; }
      EndIf
    }
  }
}

FunctionSpace {
  { Name Hgrad ; Type Form0 ; 
    BasisFunction { 
      { Name sn ; NameOfCoef vn ; Function BF_Node ; 
	Support Region[{Domaine,Armatures}]  ; Entity NodesOf[All, Not Armatures] ; }
      { Name sf ; NameOfCoef vf ; Function BF_GroupOfNodes ; 
	Support Region[{Domaine,Armatures}] ; Entity GroupsOfNodesOf[Armatures] ; }
    } 
    GlobalQuantity {
      { Name V ; Type AliasOf ; NameOfCoef vf; }
      { Name Q ; Type AssociatedWith; NameOfCoef vf; }
    }
    Constraint {
      { NameOfCoef vn  ; EntityType NodesOf ; 
	NameOfConstraint TensionsNulles ; }
      { NameOfCoef V; EntityType GroupsOfNodesOf;
	NameOfConstraint TensionImposee ; }
      { NameOfCoef Q; EntityType GroupsOfNodesOf;
	NameOfConstraint ChargeImposee ; }
    }
  }
} 

Formulation {
  { Name Electrostat ; Type FemEquation ;
    Quantity {
      { Name v  ; Type Local  ; NameOfSpace Hgrad ; }
      { Name V; Type Global; NameOfSpace Hgrad[V]; }
      { Name Q; Type Global; NameOfSpace Hgrad[Q]; }
    }
    Equation {
      Galerkin { [ eps[]*Dof{Grad v}  , {Grad v} ] ;
	In Domaine ; Jacobian Jvol ; Integration Integ ; }
           
      GlobalTerm { [ -Dof{Q} , {V} ]; In DeltaV; }

    }
  }
}

Resolution {
  { Name analyse ;
    System {
      { Name Sys ; NameOfFormulation Electrostat ; }
    }
    Operation {
      Generate[Sys] ; 
      Solve[Sys] ;
      SaveSolution[Sys] ;
    }
  }
}

PostProcessing {
  { Name PostProc ; NameOfFormulation Electrostat ;
    Quantity {	
      { Name v  ; Value { Term { [ {v} ] ; 
	    In Domaine ; Jacobian Jvol ; } } }
      { Name e  ; Value { Term { [ -{Grad v} ] ; 
	    In Domaine ; Jacobian Jvol ; } } }
      { Name d  ; Value { Term { [ -eps[]*{Grad v} ] ; 
	    In Domaine ; Jacobian Jvol ; } } }
      If (Flag_alim == 0)
	{ Name nrj ; Value { Integral { [ 2*Pi*eps[]*SquNorm[{Grad v}] ]  ; 
	    In Domaine ; Jacobian Jvol ; Integration Integ ;} } } 
	{ Name Cnrj ; Value { Integral { [ 4*Pi*eps[]*SquNorm[{Grad v}]/(V1^2) ]  ;
	      In Domaine ; Jacobian Jvol ; Integration Integ ;} } }
      EndIf
      { Name V ; Value { Term { [ {V} ]  ; In Armatures ; } } }
      { Name Q ; Value { Term { [ 2*2*Pi*{Q} ]  ; In Armatures ; } } }
      { Name C ; Value { Term { [ 2*2*Pi*{Q}/{V} ]  ; In Armatures ; } } }
    }
  }
}

PostOperation PostOp UsingPost PostProc {
  Print[ v, OnElementsOf Domaine, File "v.pos"] ;
  Print[ d, OnElementsOf Domaine, File "d.pos"] ;
  Print[ e, OnElementsOf Domaine, File "e.pos"] ;
  If (Flag_alim == 0)
    Print[ nrj[Domaine], OnGlobal, File "nrj.dat", 
      SendToServer "Modele/Resultats/1Energie (J)", Color "AliceBlue" ];
    Print[ Cnrj[Domaine], OnGlobal, File "capa.dat", 
      SendToServer "Modele/Resultats/2Capa par nrj (F)", Color "AliceBlue" ];  
  EndIf
  Print[ V, OnRegion DeltaV, File "V.txt", Color "AliceBlue",
    Format Table, SendToServer "Modele/Resultats/3Potentiel Armature (V)" ];
  Print[ Q, OnRegion DeltaV, File "Q.txt", Color "AliceBlue",
    Format Table, SendToServer "Modele/Resultats/4Charge Armature (C)" ];
  Print[ C, OnRegion DeltaV, File "C.txt", Color "AliceBlue",
    Format Table, SendToServer "Modele/Resultats/5Capa (F)" ];
}